# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class InformationAboutUserApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_additional_email_using_post(self, additional_email_request, **kwargs):  # noqa: E501
        """Add a new additional email address to user's account  # noqa: E501

        Use this resource to add a new additional email address to account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_additional_email_using_post(additional_email_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AdditionalEmailRequest additional_email_request: request (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AdditionalEmail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_additional_email_using_post_with_http_info(additional_email_request, **kwargs)  # noqa: E501

    def add_additional_email_using_post_with_http_info(self, additional_email_request, **kwargs):  # noqa: E501
        """Add a new additional email address to user's account  # noqa: E501

        Use this resource to add a new additional email address to account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_additional_email_using_post_with_http_info(additional_email_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AdditionalEmailRequest additional_email_request: request (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AdditionalEmail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['additional_email_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_additional_email_using_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'additional_email_request' is set
        if self.api_client.client_side_validation and ('additional_email_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['additional_email_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `additional_email_request` when calling `add_additional_email_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'additional_email_request' in local_var_params:
            body_params = local_var_params['additional_email_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json', '*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/account/additional-emails', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AdditionalEmail',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def answer_user_rating_using_put(self, rating_id, user_rating_answer_request, **kwargs):  # noqa: E501
        """Answer for user's rating  # noqa: E501

        Use this resource to answer for received rating.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.answer_user_rating_using_put(rating_id, user_rating_answer_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str rating_id: ID of the rating. (required)
        :param UserRatingAnswerRequest user_rating_answer_request: User rating answer request. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Answer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.answer_user_rating_using_put_with_http_info(rating_id, user_rating_answer_request, **kwargs)  # noqa: E501

    def answer_user_rating_using_put_with_http_info(self, rating_id, user_rating_answer_request, **kwargs):  # noqa: E501
        """Answer for user's rating  # noqa: E501

        Use this resource to answer for received rating.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.answer_user_rating_using_put_with_http_info(rating_id, user_rating_answer_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str rating_id: ID of the rating. (required)
        :param UserRatingAnswerRequest user_rating_answer_request: User rating answer request. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Answer, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['rating_id', 'user_rating_answer_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method answer_user_rating_using_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'rating_id' is set
        if self.api_client.client_side_validation and ('rating_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['rating_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rating_id` when calling `answer_user_rating_using_put`")  # noqa: E501
        # verify the required parameter 'user_rating_answer_request' is set
        if self.api_client.client_side_validation and ('user_rating_answer_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_rating_answer_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_rating_answer_request` when calling `answer_user_rating_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'rating_id' in local_var_params:
            path_params['ratingId'] = local_var_params['rating_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_rating_answer_request' in local_var_params:
            body_params = local_var_params['user_rating_answer_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/user-ratings/{ratingId}/answer', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Answer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_additional_email_using_delete(self, email_id, **kwargs):  # noqa: E501
        """Delete an additional email address  # noqa: E501

        Use this resource to delete one of additional emails.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_additional_email_using_delete(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: Id of the additional email to be deleted. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_additional_email_using_delete_with_http_info(email_id, **kwargs)  # noqa: E501

    def delete_additional_email_using_delete_with_http_info(self, email_id, **kwargs):  # noqa: E501
        """Delete an additional email address  # noqa: E501

        Use this resource to delete one of additional emails.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_additional_email_using_delete_with_http_info(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: Id of the additional email to be deleted. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['email_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_additional_email_using_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'email_id' is set
        if self.api_client.client_side_validation and ('email_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['email_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `email_id` when calling `delete_additional_email_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'email_id' in local_var_params:
            path_params['emailId'] = local_var_params['email_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json', '*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/account/additional-emails/{emailId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_additional_email_using_get(self, email_id, **kwargs):  # noqa: E501
        """Get information about a particular additional email  # noqa: E501

        Use this resource to retrieve a single additional email.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_additional_email_using_get(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: Id of the additional email. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AdditionalEmail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_additional_email_using_get_with_http_info(email_id, **kwargs)  # noqa: E501

    def get_additional_email_using_get_with_http_info(self, email_id, **kwargs):  # noqa: E501
        """Get information about a particular additional email  # noqa: E501

        Use this resource to retrieve a single additional email.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_additional_email_using_get_with_http_info(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: Id of the additional email. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AdditionalEmail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['email_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_additional_email_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'email_id' is set
        if self.api_client.client_side_validation and ('email_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['email_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `email_id` when calling `get_additional_email_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'email_id' in local_var_params:
            path_params['emailId'] = local_var_params['email_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json', '*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/account/additional-emails/{emailId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AdditionalEmail',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_list_of_additional_emails_using_get(self, **kwargs):  # noqa: E501
        """Get user's additional emails  # noqa: E501

        Use this resource to get a list of all additional email addresses assigned to account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_list_of_additional_emails_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AdditionalEmailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_list_of_additional_emails_using_get_with_http_info(**kwargs)  # noqa: E501

    def get_list_of_additional_emails_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get user's additional emails  # noqa: E501

        Use this resource to get a list of all additional email addresses assigned to account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_list_of_additional_emails_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AdditionalEmailsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_list_of_additional_emails_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json', '*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/account/additional-emails', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AdditionalEmailsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_ratings_using_get(self, user_id, **kwargs):  # noqa: E501
        """Get the user's ratings  # noqa: E501

        Use this resource to receive your sales score. <a href=\"../../news/2017-10-09-news_informacje_o_ocenach/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_ratings_using_get(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: Filter by user id, you are allowed to get your ratings only. (required)
        :param str recommended: Filter by recommended.
        :param int offset: The offset of elements in the response.
        :param int limit: The limit of elements in the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserRatingListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_user_ratings_using_get_with_http_info(user_id, **kwargs)  # noqa: E501

    def get_user_ratings_using_get_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Get the user's ratings  # noqa: E501

        Use this resource to receive your sales score. <a href=\"../../news/2017-10-09-news_informacje_o_ocenach/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_ratings_using_get_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: Filter by user id, you are allowed to get your ratings only. (required)
        :param str recommended: Filter by recommended.
        :param int offset: The offset of elements in the response.
        :param int limit: The limit of elements in the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserRatingListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id', 'recommended', 'offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_ratings_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_id` when calling `get_user_ratings_using_get`")  # noqa: E501

        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] > 20000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_user_ratings_using_get`, must be a value less than or equal to `20000`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_user_ratings_using_get`, must be a value greater than or equal to `0`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_user_ratings_using_get`, must be a value less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_user_ratings_using_get`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user.id', local_var_params['user_id']))  # noqa: E501
        if 'recommended' in local_var_params and local_var_params['recommended'] is not None:  # noqa: E501
            query_params.append(('recommended', local_var_params['recommended']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/user-ratings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserRatingListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def me_get(self, **kwargs):  # noqa: E501
        """Get basic information about user  # noqa: E501

        Use this resource when you need basic information about authenticated user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.me_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.me_get_with_http_info(**kwargs)  # noqa: E501

    def me_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get basic information about user  # noqa: E501

        Use this resource when you need basic information about authenticated user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.me_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MeResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method me_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/me', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_rating_removal_using_put(self, rating_id, user_rating_removal_request, **kwargs):  # noqa: E501
        """Request removal of user's rating  # noqa: E501

        Use this resource to request removal of received rating.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_rating_removal_using_put(rating_id, user_rating_removal_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str rating_id: ID of the rating. (required)
        :param UserRatingRemovalRequest user_rating_removal_request: User rating removal request. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Removal
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.user_rating_removal_using_put_with_http_info(rating_id, user_rating_removal_request, **kwargs)  # noqa: E501

    def user_rating_removal_using_put_with_http_info(self, rating_id, user_rating_removal_request, **kwargs):  # noqa: E501
        """Request removal of user's rating  # noqa: E501

        Use this resource to request removal of received rating.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_rating_removal_using_put_with_http_info(rating_id, user_rating_removal_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str rating_id: ID of the rating. (required)
        :param UserRatingRemovalRequest user_rating_removal_request: User rating removal request. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Removal, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['rating_id', 'user_rating_removal_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_rating_removal_using_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'rating_id' is set
        if self.api_client.client_side_validation and ('rating_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['rating_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rating_id` when calling `user_rating_removal_using_put`")  # noqa: E501
        # verify the required parameter 'user_rating_removal_request' is set
        if self.api_client.client_side_validation and ('user_rating_removal_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_rating_removal_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_rating_removal_request` when calling `user_rating_removal_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'rating_id' in local_var_params:
            path_params['ratingId'] = local_var_params['rating_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_rating_removal_request' in local_var_params:
            body_params = local_var_params['user_rating_removal_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/user-ratings/{ratingId}/removal', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Removal',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.public_tables_dto import PublicTablesDto  # noqa: E501
from allegro_api.rest import ApiException

class TestPublicTablesDto(unittest.TestCase):
    """PublicTablesDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PublicTablesDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.public_tables_dto.PublicTablesDto()  # noqa: E501
        if include_optional :
            return PublicTablesDto(
                tables = [
                    allegro_api.models.public_table_dto.PublicTableDto(
                        headers = [
                            allegro_api.models.header.Header(
                                name = '0', )
                            ], 
                        id = '0', 
                        image = allegro_api.models.public_table_image_dto.PublicTableImageDto(
                            captions = [
                                allegro_api.models.caption.Caption(
                                    index = '0', 
                                    value = '0', )
                                ], 
                            url = '0', ), 
                        name = '0', 
                        orientation = 'HORIZONTAL', 
                        values = [
                            allegro_api.models.cells.Cells(
                                cells = [
                                    '0'
                                    ], )
                            ], )
                    ]
            )
        else :
            return PublicTablesDto(
                tables = [
                    allegro_api.models.public_table_dto.PublicTableDto(
                        headers = [
                            allegro_api.models.header.Header(
                                name = '0', )
                            ], 
                        id = '0', 
                        image = allegro_api.models.public_table_image_dto.PublicTableImageDto(
                            captions = [
                                allegro_api.models.caption.Caption(
                                    index = '0', 
                                    value = '0', )
                                ], 
                            url = '0', ), 
                        name = '0', 
                        orientation = 'HORIZONTAL', 
                        values = [
                            allegro_api.models.cells.Cells(
                                cells = [
                                    '0'
                                    ], )
                            ], )
                    ],
        )

    def testPublicTablesDto(self):
        """Test PublicTablesDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class ListingResponseSearchMeta(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'available_count': 'int',
        'total_count': 'int',
        'fallback': 'bool'
    }

    attribute_map = {
        'available_count': 'availableCount',
        'total_count': 'totalCount',
        'fallback': 'fallback'
    }

    def __init__(self, available_count=None, total_count=None, fallback=None, local_vars_configuration=None):  # noqa: E501
        """ListingResponseSearchMeta - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._available_count = None
        self._total_count = None
        self._fallback = None
        self.discriminator = None

        if available_count is not None:
            self.available_count = available_count
        if total_count is not None:
            self.total_count = total_count
        if fallback is not None:
            self.fallback = fallback

    @property
    def available_count(self):
        """Gets the available_count of this ListingResponseSearchMeta.  # noqa: E501

        The number of results available for navigation. If this number is less than total count, the search criteria (categories, filters, etc.) should be narrowed down to make all results available.  # noqa: E501

        :return: The available_count of this ListingResponseSearchMeta.  # noqa: E501
        :rtype: int
        """
        return self._available_count

    @available_count.setter
    def available_count(self, available_count):
        """Sets the available_count of this ListingResponseSearchMeta.

        The number of results available for navigation. If this number is less than total count, the search criteria (categories, filters, etc.) should be narrowed down to make all results available.  # noqa: E501

        :param available_count: The available_count of this ListingResponseSearchMeta.  # noqa: E501
        :type: int
        """

        self._available_count = available_count

    @property
    def total_count(self):
        """Gets the total_count of this ListingResponseSearchMeta.  # noqa: E501

        The total number of search results with given parameters.  # noqa: E501

        :return: The total_count of this ListingResponseSearchMeta.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListingResponseSearchMeta.

        The total number of search results with given parameters.  # noqa: E501

        :param total_count: The total_count of this ListingResponseSearchMeta.  # noqa: E501
        :type: int
        """

        self._total_count = total_count

    @property
    def fallback(self):
        """Gets the fallback of this ListingResponseSearchMeta.  # noqa: E501

        Indicates whether the search fallback was used. If true, no items matching exact given phrase were found and related items are presented.  # noqa: E501

        :return: The fallback of this ListingResponseSearchMeta.  # noqa: E501
        :rtype: bool
        """
        return self._fallback

    @fallback.setter
    def fallback(self, fallback):
        """Sets the fallback of this ListingResponseSearchMeta.

        Indicates whether the search fallback was used. If true, no items matching exact given phrase were found and related items are presented.  # noqa: E501

        :param fallback: The fallback of this ListingResponseSearchMeta.  # noqa: E501
        :type: bool
        """

        self._fallback = fallback

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListingResponseSearchMeta):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListingResponseSearchMeta):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.offer_selling_mode import OfferSellingMode  # noqa: E501
from allegro_api.rest import ApiException

class TestOfferSellingMode(unittest.TestCase):
    """OfferSellingMode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OfferSellingMode
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.offer_selling_mode.OfferSellingMode()  # noqa: E501
        if include_optional :
            return OfferSellingMode(
                format = 'BUY_NOW', 
                price = allegro_api.models.offer_price.OfferPrice(
                    amount = '123.45', 
                    currency = 'PLN', ), 
                fixed_price = allegro_api.models.offer_fixed_price.OfferFixedPrice(
                    amount = '123.45', 
                    currency = 'PLN', ), 
                popularity = 38, 
                bid_count = 12
            )
        else :
            return OfferSellingMode(
        )

    def testOfferSellingMode(self):
        """Test OfferSellingMode"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.contacts_api import ContactsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestContactsApi(unittest.TestCase):
    """ContactsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.contacts_api.ContactsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_contact_using_post(self):
        """Test case for create_contact_using_post

        Create a new contact  # noqa: E501
        """
        pass

    def test_get_contact_using_get(self):
        """Test case for get_contact_using_get

        Get contact details  # noqa: E501
        """
        pass

    def test_get_list_of_contacts_using_get(self):
        """Test case for get_list_of_contacts_using_get

        Get the user's contacts  # noqa: E501
        """
        pass

    def test_modify_contact_using_put(self):
        """Test case for modify_contact_using_put

        Modify contact details  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.batch_offer_modification_api import BatchOfferModificationApi  # noqa: E501
from allegro_api.rest import ApiException


class TestBatchOfferModificationApi(unittest.TestCase):
    """BatchOfferModificationApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.batch_offer_modification_api.BatchOfferModificationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_general_report_using_get(self):
        """Test case for get_general_report_using_get

        Modification command summary  # noqa: E501
        """
        pass

    def test_get_price_modification_command_status_using_get(self):
        """Test case for get_price_modification_command_status_using_get

        Change price command summary  # noqa: E501
        """
        pass

    def test_get_price_modification_command_tasks_statuses_using_get(self):
        """Test case for get_price_modification_command_tasks_statuses_using_get

        Change price command detailed report  # noqa: E501
        """
        pass

    def test_get_quantity_modification_command_status_using_get(self):
        """Test case for get_quantity_modification_command_status_using_get

        Change quantity command summary  # noqa: E501
        """
        pass

    def test_get_quantity_modification_command_tasks_statuses_using_get(self):
        """Test case for get_quantity_modification_command_tasks_statuses_using_get

        Change quantity command detailed report  # noqa: E501
        """
        pass

    def test_get_tasks_using_get(self):
        """Test case for get_tasks_using_get

        Modification command detailed report  # noqa: E501
        """
        pass

    def test_modification_command_using_put(self):
        """Test case for modification_command_using_put

        Batch offer modification  # noqa: E501
        """
        pass

    def test_price_modification_command_using_put(self):
        """Test case for price_modification_command_using_put

        Batch offer price modification  # noqa: E501
        """
        pass

    def test_quantity_modification_command_using_put(self):
        """Test case for quantity_modification_command_using_put

        Batch offer quantity modification  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.badge_campaign import BadgeCampaign  # noqa: E501
from allegro_api.rest import ApiException

class TestBadgeCampaign(unittest.TestCase):
    """BadgeCampaign unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test BadgeCampaign
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.badge_campaign.BadgeCampaign()  # noqa: E501
        if include_optional :
            return BadgeCampaign(
                id = 'BARGAIN', 
                name = 'Strefa Okazji', 
                type = 'DISCOUNT', 
                eligibility = allegro_api.models.user_campaign_eligibility.UserCampaignEligibility(
                    eligible = True, 
                    refusal_reasons = [
                        allegro_api.models.campaign_refusal_reason.CampaignRefusalReason(
                            code = '0', 
                            messages = [
                                allegro_api.models.refusal_message.RefusalMessage(
                                    text = '0', 
                                    link = '0', )
                                ], )
                        ], ), 
                application = {"type":"UNTIL","to":"2012-12-03T10:15:30Z"}, 
                visibility = {"type":"UNTIL","to":"2012-12-03T10:15:30Z"}, 
                publication = {"type":"UNTIL","to":"2012-12-03T10:15:30Z"}
            )
        else :
            return BadgeCampaign(
                id = 'BARGAIN',
                name = 'Strefa Okazji',
                type = 'DISCOUNT',
                eligibility = allegro_api.models.user_campaign_eligibility.UserCampaignEligibility(
                    eligible = True, 
                    refusal_reasons = [
                        allegro_api.models.campaign_refusal_reason.CampaignRefusalReason(
                            code = '0', 
                            messages = [
                                allegro_api.models.refusal_message.RefusalMessage(
                                    text = '0', 
                                    link = '0', )
                                ], )
                        ], ),
                application = {"type":"UNTIL","to":"2012-12-03T10:15:30Z"},
                visibility = {"type":"UNTIL","to":"2012-12-03T10:15:30Z"},
                publication = {"type":"UNTIL","to":"2012-12-03T10:15:30Z"},
        )

    def testBadgeCampaign(self):
        """Test BadgeCampaign"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.participant import Participant  # noqa: E501
from allegro_api.rest import ApiException

class TestParticipant(unittest.TestCase):
    """Participant unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Participant
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.participant.Participant()  # noqa: E501
        if include_optional :
            return Participant(
                company_name = 'Allegro', 
                login = 'User_login', 
                first_name = 'Jan', 
                last_name = 'Nowak', 
                address = allegro_api.models.operation_participant_address.OperationParticipantAddress(
                    street = 'Grunwaldzka 108', 
                    city = 'Poznań', 
                    post_code = '60-166', )
            )
        else :
            return Participant(
                login = 'User_login',
                first_name = 'Jan',
                last_name = 'Nowak',
        )

    def testParticipant(self):
        """Test Participant"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class PublicOfferInformationApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_listing(self, **kwargs):  # noqa: E501
        """Search offers  # noqa: E501

        Use this resource to get a list of offers based on the provided query parameters. At least one of: phrase, seller.id or category.id is required. Additional available parameters vary depending on category.id. The parameters are defined in the filters entity. <a href=\"../../news/2018-07-03-listing_ofert/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_listing(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str category_id: The identifier of the category, where you want to search for offers.
        :param str phrase: The search phrase. The phrase is searched in different fields of the offers depending on the value of the `searchMode` parameter.
        :param str seller_id: The identifier of a seller, to limit the results to offers from this seller. May be provided more than once.
        :param str search_mode: Defines where the given phrase should be searched in. Allowed values:    - *REGULAR* - searching for a phrase in the title,   - *DESCRIPTIONS* - searching for a phrase in the title and the descriptions,   - *CLOSED* - searching for a phrase in the title of closed offers.
        :param int offset: Index of the first returned offer from all search results.
        :param int limit: The maximum number of offers in a response.
        :param str sort: Search results sorting order. `+` or no prefix in the value means ascending order. `-` prefix means descending order.
        :param str include: Specify parts of the response that should be included in the output. Allowed values are the names of top level entities and *all* as an alias to all entities. By default, all top level entities are included. Use `-` prefix to exclude an entity. Example: `include=-all&include=filters&include=sort` - returns only filters and sort entities.
        :param bool fallback: Defines the behaviour of the search engine when no results with exact phrase match are found:    - *true* - related (not exact) results are returned,   - *false* - empty results are returned.
        :param dict(str, str) dynamic_filters: You can filter and customize your search results to find exactly what you need by applying filters ids and their dictionary values to query according to the flowing pattern: id=value. When the filter definition looks like:   ````     {      \"id\": \"parameter.11323\",      \"type\": \"MULTI\",      \"name\": \"Stan\",      \"values\": [{        \"value\": \"11323_1\",        \"name\": \"nowe\",        \"count\": 21,        \"selected\": false       },       {        \"value\": \"11323_2\",        \"name\": \"używane\",        \"count\": 157,        \"selected\": false       },       {        \"value\": \"11323_238066\",        \"name\": \"po zwrocie\",        \"count\": 1,        \"selected\": false       }      ]     }   ```` You can use 'Stan' filter to query results, i.e.:   * `parameter.11323=11323_1` for \"nowe\"   * `parameter.11323=11323_2` for \"używane\"   * `parameter.11323=11323_238066` for \"po zwrocie\".
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_listing_with_http_info(**kwargs)  # noqa: E501

    def get_listing_with_http_info(self, **kwargs):  # noqa: E501
        """Search offers  # noqa: E501

        Use this resource to get a list of offers based on the provided query parameters. At least one of: phrase, seller.id or category.id is required. Additional available parameters vary depending on category.id. The parameters are defined in the filters entity. <a href=\"../../news/2018-07-03-listing_ofert/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_listing_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str category_id: The identifier of the category, where you want to search for offers.
        :param str phrase: The search phrase. The phrase is searched in different fields of the offers depending on the value of the `searchMode` parameter.
        :param str seller_id: The identifier of a seller, to limit the results to offers from this seller. May be provided more than once.
        :param str search_mode: Defines where the given phrase should be searched in. Allowed values:    - *REGULAR* - searching for a phrase in the title,   - *DESCRIPTIONS* - searching for a phrase in the title and the descriptions,   - *CLOSED* - searching for a phrase in the title of closed offers.
        :param int offset: Index of the first returned offer from all search results.
        :param int limit: The maximum number of offers in a response.
        :param str sort: Search results sorting order. `+` or no prefix in the value means ascending order. `-` prefix means descending order.
        :param str include: Specify parts of the response that should be included in the output. Allowed values are the names of top level entities and *all* as an alias to all entities. By default, all top level entities are included. Use `-` prefix to exclude an entity. Example: `include=-all&include=filters&include=sort` - returns only filters and sort entities.
        :param bool fallback: Defines the behaviour of the search engine when no results with exact phrase match are found:    - *true* - related (not exact) results are returned,   - *false* - empty results are returned.
        :param dict(str, str) dynamic_filters: You can filter and customize your search results to find exactly what you need by applying filters ids and their dictionary values to query according to the flowing pattern: id=value. When the filter definition looks like:   ````     {      \"id\": \"parameter.11323\",      \"type\": \"MULTI\",      \"name\": \"Stan\",      \"values\": [{        \"value\": \"11323_1\",        \"name\": \"nowe\",        \"count\": 21,        \"selected\": false       },       {        \"value\": \"11323_2\",        \"name\": \"używane\",        \"count\": 157,        \"selected\": false       },       {        \"value\": \"11323_238066\",        \"name\": \"po zwrocie\",        \"count\": 1,        \"selected\": false       }      ]     }   ```` You can use 'Stan' filter to query results, i.e.:   * `parameter.11323=11323_1` for \"nowe\"   * `parameter.11323=11323_2` for \"używane\"   * `parameter.11323=11323_238066` for \"po zwrocie\".
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListingResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['category_id', 'phrase', 'seller_id', 'search_mode', 'offset', 'limit', 'sort', 'include', 'fallback', 'dynamic_filters']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_listing" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_listing`, must be a value less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_listing`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'category_id' in local_var_params and local_var_params['category_id'] is not None:  # noqa: E501
            query_params.append(('category.id', local_var_params['category_id']))  # noqa: E501
        if 'phrase' in local_var_params and local_var_params['phrase'] is not None:  # noqa: E501
            query_params.append(('phrase', local_var_params['phrase']))  # noqa: E501
        if 'seller_id' in local_var_params and local_var_params['seller_id'] is not None:  # noqa: E501
            query_params.append(('seller.id', local_var_params['seller_id']))  # noqa: E501
        if 'search_mode' in local_var_params and local_var_params['search_mode'] is not None:  # noqa: E501
            query_params.append(('searchMode', local_var_params['search_mode']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'include' in local_var_params and local_var_params['include'] is not None:  # noqa: E501
            query_params.append(('include', local_var_params['include']))  # noqa: E501
        if 'fallback' in local_var_params and local_var_params['fallback'] is not None:  # noqa: E501
            query_params.append(('fallback', local_var_params['fallback']))  # noqa: E501
        if 'dynamic_filters' in local_var_params and local_var_params['dynamic_filters'] is not None:  # noqa: E501
            query_params.append(('Dynamic filters', local_var_params['dynamic_filters']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-application', 'bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/offers/listing', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.badge import Badge  # noqa: E501
from allegro_api.rest import ApiException

class TestBadge(unittest.TestCase):
    """Badge unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Badge
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.badge.Badge()  # noqa: E501
        if include_optional :
            return Badge(
                offer = allegro_api.models.badge_offer.BadgeOffer(
                    id = '987654321', ), 
                campaign = allegro_api.models.offer_badge_campaign.OfferBadgeCampaign(
                    id = 'BARGAIN', 
                    name = 'Strefa Okazji', ), 
                publication = {"type":"UNTIL","to":"2012-12-03T10:15:30.000Z"}, 
                prices = allegro_api.models.badge_prices.BadgePrices(
                    market = allegro_api.models.badge_application_market_price.BadgeApplicationMarketPrice(
                        amount = '1.23', 
                        currency = 'PLN', ), 
                    bargain = allegro_api.models.badge_application_bargain_price.BadgeApplicationBargainPrice(
                        amount = '1.23', 
                        currency = 'PLN', ), ), 
                process = allegro_api.models.badge_process.BadgeProcess(
                    status = 'IN_VERIFICATION', 
                    rejection_reasons = [
                        allegro_api.models.rejection_reason.RejectionReason(
                            code = '0', 
                            messages = [
                                allegro_api.models.badge_application_rejection_reason_message.BadgeApplicationRejectionReasonMessage(
                                    text = 'See requirements.', 
                                    link = 'https://allegro.pl/regulamin/pl', )
                                ], )
                        ], )
            )
        else :
            return Badge(
                offer = allegro_api.models.badge_offer.BadgeOffer(
                    id = '987654321', ),
                campaign = allegro_api.models.offer_badge_campaign.OfferBadgeCampaign(
                    id = 'BARGAIN', 
                    name = 'Strefa Okazji', ),
                process = allegro_api.models.badge_process.BadgeProcess(
                    status = 'IN_VERIFICATION', 
                    rejection_reasons = [
                        allegro_api.models.rejection_reason.RejectionReason(
                            code = '0', 
                            messages = [
                                allegro_api.models.badge_application_rejection_reason_message.BadgeApplicationRejectionReasonMessage(
                                    text = 'See requirements.', 
                                    link = 'https://allegro.pl/regulamin/pl', )
                                ], )
                        ], ),
        )

    def testBadge(self):
        """Test Badge"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class OrderEventData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'seller': 'SellerReference',
        'buyer': 'BuyerReference',
        'line_items': 'list[OrderLineItem]',
        'checkout_form': 'CheckoutFormReference'
    }

    attribute_map = {
        'seller': 'seller',
        'buyer': 'buyer',
        'line_items': 'lineItems',
        'checkout_form': 'checkoutForm'
    }

    def __init__(self, seller=None, buyer=None, line_items=None, checkout_form=None, local_vars_configuration=None):  # noqa: E501
        """OrderEventData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._seller = None
        self._buyer = None
        self._line_items = None
        self._checkout_form = None
        self.discriminator = None

        self.seller = seller
        self.buyer = buyer
        self.line_items = line_items
        if checkout_form is not None:
            self.checkout_form = checkout_form

    @property
    def seller(self):
        """Gets the seller of this OrderEventData.  # noqa: E501


        :return: The seller of this OrderEventData.  # noqa: E501
        :rtype: SellerReference
        """
        return self._seller

    @seller.setter
    def seller(self, seller):
        """Sets the seller of this OrderEventData.


        :param seller: The seller of this OrderEventData.  # noqa: E501
        :type: SellerReference
        """
        if self.local_vars_configuration.client_side_validation and seller is None:  # noqa: E501
            raise ValueError("Invalid value for `seller`, must not be `None`")  # noqa: E501

        self._seller = seller

    @property
    def buyer(self):
        """Gets the buyer of this OrderEventData.  # noqa: E501


        :return: The buyer of this OrderEventData.  # noqa: E501
        :rtype: BuyerReference
        """
        return self._buyer

    @buyer.setter
    def buyer(self, buyer):
        """Sets the buyer of this OrderEventData.


        :param buyer: The buyer of this OrderEventData.  # noqa: E501
        :type: BuyerReference
        """
        if self.local_vars_configuration.client_side_validation and buyer is None:  # noqa: E501
            raise ValueError("Invalid value for `buyer`, must not be `None`")  # noqa: E501

        self._buyer = buyer

    @property
    def line_items(self):
        """Gets the line_items of this OrderEventData.  # noqa: E501


        :return: The line_items of this OrderEventData.  # noqa: E501
        :rtype: list[OrderLineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this OrderEventData.


        :param line_items: The line_items of this OrderEventData.  # noqa: E501
        :type: list[OrderLineItem]
        """
        if self.local_vars_configuration.client_side_validation and line_items is None:  # noqa: E501
            raise ValueError("Invalid value for `line_items`, must not be `None`")  # noqa: E501

        self._line_items = line_items

    @property
    def checkout_form(self):
        """Gets the checkout_form of this OrderEventData.  # noqa: E501


        :return: The checkout_form of this OrderEventData.  # noqa: E501
        :rtype: CheckoutFormReference
        """
        return self._checkout_form

    @checkout_form.setter
    def checkout_form(self, checkout_form):
        """Sets the checkout_form of this OrderEventData.


        :param checkout_form: The checkout_form of this OrderEventData.  # noqa: E501
        :type: CheckoutFormReference
        """

        self._checkout_form = checkout_form

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderEventData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrderEventData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.listing_offer import ListingOffer  # noqa: E501
from allegro_api.rest import ApiException

class TestListingOffer(unittest.TestCase):
    """ListingOffer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListingOffer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.listing_offer.ListingOffer()  # noqa: E501
        if include_optional :
            return ListingOffer(
                id = '2865624934', 
                name = 'Buty damskie adidas', 
                seller = allegro_api.models.offer_seller.OfferSeller(
                    id = '41846511', 
                    company = True, 
                    super_seller = True, ), 
                promotion = allegro_api.models.offer_promotion.OfferPromotion(
                    emphasized = True, 
                    bold = True, 
                    highlight = True, ), 
                delivery = allegro_api.models.offer_delivery.OfferDelivery(
                    available_for_free = True, 
                    lowest_price = allegro_api.models.offer_lowest_price.OfferLowestPrice(
                        amount = '123.45', 
                        currency = 'PLN', ), ), 
                images = [
                    allegro_api.models.offer_images.OfferImages(
                        url = 'https://a.allegroimg.com/original/0129e7/f15ce8924166850eec3fb82bcd5s/BUTY-ADIDAS-DAMSKIE', )
                    ], 
                selling_mode = allegro_api.models.offer_selling_mode.OfferSellingMode(
                    format = 'BUY_NOW', 
                    price = allegro_api.models.offer_price.OfferPrice(
                        amount = '123.45', 
                        currency = 'PLN', ), 
                    fixed_price = allegro_api.models.offer_fixed_price.OfferFixedPrice(
                        amount = '123.45', 
                        currency = 'PLN', ), 
                    popularity = 38, 
                    bid_count = 12, ), 
                stock = allegro_api.models.offer_stock.OfferStock(
                    unit = 'UNIT', 
                    available = 23, ), 
                vendor = allegro_api.models.offer_vendor.OfferVendor(
                    id = 'CHARYTATYWNI_ALLEGRO', 
                    url = 'http://charytatywni.allegro.pl/oferta-charytatywna-i1234567', ), 
                category = allegro_api.models.offer_category.OfferCategory(
                    id = '257929', ), 
                publication = allegro_api.models.offer_publication.OfferPublication(
                    ending_at = '2019-05-15T18:09:41.000Z', )
            )
        else :
            return ListingOffer(
        )

    def testListingOffer(self):
        """Test ListingOffer"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.command_task import CommandTask  # noqa: E501
from allegro_api.rest import ApiException

class TestCommandTask(unittest.TestCase):
    """CommandTask unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CommandTask
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.command_task.CommandTask()  # noqa: E501
        if include_optional :
            return CommandTask(
                field = '0', 
                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                message = '0', 
                offer = allegro_api.models.offer_id.OfferId(
                    id = '0', ), 
                scheduled_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                status = '0', 
                errors = [
                    allegro_api.models.error.Error(
                        code = 'NotAcceptableException', 
                        details = '0', 
                        message = 'Not acceptable representation requested. Please check 'Accept' request header', 
                        path = '0', 
                        user_message = 'The request contains incorrect data. Contact the author of the application.', )
                    ]
            )
        else :
            return CommandTask(
        )

    def testCommandTask(self):
        """Test CommandTask"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class Publication(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'duration': 'str',
        'ending_at': 'datetime',
        'starting_at': 'datetime',
        'status': 'OfferStatus',
        'ended_by': 'str',
        'republish': 'bool'
    }

    attribute_map = {
        'duration': 'duration',
        'ending_at': 'endingAt',
        'starting_at': 'startingAt',
        'status': 'status',
        'ended_by': 'endedBy',
        'republish': 'republish'
    }

    def __init__(self, duration=None, ending_at=None, starting_at=None, status=None, ended_by=None, republish=None, local_vars_configuration=None):  # noqa: E501
        """Publication - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._duration = None
        self._ending_at = None
        self._starting_at = None
        self._status = None
        self._ended_by = None
        self._republish = None
        self.discriminator = None

        if duration is not None:
            self.duration = duration
        if ending_at is not None:
            self.ending_at = ending_at
        if starting_at is not None:
            self.starting_at = starting_at
        if status is not None:
            self.status = status
        if ended_by is not None:
            self.ended_by = ended_by
        if republish is not None:
            self.republish = republish

    @property
    def duration(self):
        """Gets the duration of this Publication.  # noqa: E501

        Publication duration, ISO 8601 duration format  # noqa: E501

        :return: The duration of this Publication.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this Publication.

        Publication duration, ISO 8601 duration format  # noqa: E501

        :param duration: The duration of this Publication.  # noqa: E501
        :type: str
        """

        self._duration = duration

    @property
    def ending_at(self):
        """Gets the ending_at of this Publication.  # noqa: E501

        Publication ending date: Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ. Cannot be modified  # noqa: E501

        :return: The ending_at of this Publication.  # noqa: E501
        :rtype: datetime
        """
        return self._ending_at

    @ending_at.setter
    def ending_at(self, ending_at):
        """Sets the ending_at of this Publication.

        Publication ending date: Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ. Cannot be modified  # noqa: E501

        :param ending_at: The ending_at of this Publication.  # noqa: E501
        :type: datetime
        """

        self._ending_at = ending_at

    @property
    def starting_at(self):
        """Gets the starting_at of this Publication.  # noqa: E501

        Publication starting date: Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ. Cannot be modified  # noqa: E501

        :return: The starting_at of this Publication.  # noqa: E501
        :rtype: datetime
        """
        return self._starting_at

    @starting_at.setter
    def starting_at(self, starting_at):
        """Sets the starting_at of this Publication.

        Publication starting date: Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ. Cannot be modified  # noqa: E501

        :param starting_at: The starting_at of this Publication.  # noqa: E501
        :type: datetime
        """

        self._starting_at = starting_at

    @property
    def status(self):
        """Gets the status of this Publication.  # noqa: E501


        :return: The status of this Publication.  # noqa: E501
        :rtype: OfferStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Publication.


        :param status: The status of this Publication.  # noqa: E501
        :type: OfferStatus
        """

        self._status = status

    @property
    def ended_by(self):
        """Gets the ended_by of this Publication.  # noqa: E501

        Indicates the reason for ending the offer:  - `USER` - offer ended by the seller.  - `ADMIN` - offer ended by an admin.  - `EXPIRATION` - offer ended because all available items had been sold out or offer duration had expired (valid for    offers with specified duration).  - `ERROR` - offer ended due to internal problem with offer publication. The publication command responded with    success status, but further processing failed.  # noqa: E501

        :return: The ended_by of this Publication.  # noqa: E501
        :rtype: str
        """
        return self._ended_by

    @ended_by.setter
    def ended_by(self, ended_by):
        """Sets the ended_by of this Publication.

        Indicates the reason for ending the offer:  - `USER` - offer ended by the seller.  - `ADMIN` - offer ended by an admin.  - `EXPIRATION` - offer ended because all available items had been sold out or offer duration had expired (valid for    offers with specified duration).  - `ERROR` - offer ended due to internal problem with offer publication. The publication command responded with    success status, but further processing failed.  # noqa: E501

        :param ended_by: The ended_by of this Publication.  # noqa: E501
        :type: str
        """
        allowed_values = ["USER", "ADMIN", "EXPIRATION", "ERROR"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and ended_by not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `ended_by` ({0}), must be one of {1}"  # noqa: E501
                .format(ended_by, allowed_values)
            )

        self._ended_by = ended_by

    @property
    def republish(self):
        """Gets the republish of this Publication.  # noqa: E501

        Whether to republish an offer after ending. Automatically republish offers or auctions:</br> - `BUY_NOW` offer type are republished with initial stock, regardless of how many items you have sold.</br> - `AUCTION` offer type are republished only if they were not concluded with purchase.</br> - `ADVERTISEMENT` offer type cannot be republished.  # noqa: E501

        :return: The republish of this Publication.  # noqa: E501
        :rtype: bool
        """
        return self._republish

    @republish.setter
    def republish(self, republish):
        """Sets the republish of this Publication.

        Whether to republish an offer after ending. Automatically republish offers or auctions:</br> - `BUY_NOW` offer type are republished with initial stock, regardless of how many items you have sold.</br> - `AUCTION` offer type are republished only if they were not concluded with purchase.</br> - `ADVERTISEMENT` offer type cannot be republished.  # noqa: E501

        :param republish: The republish of this Publication.  # noqa: E501
        :type: bool
        """

        self._republish = republish

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Publication):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Publication):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class ParametersForPreviewPrice(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'category': 'Category',
        'condition': 'str',
        'duration': 'str',
        'has_any_quantity': 'bool',
        'number_of_big_photos': 'int',
        'number_of_photos': 'int',
        'quantity': 'int',
        'shop': 'bool',
        'sold_quantity': 'int',
        'type': 'str',
        'unit_price': 'float',
        'bold': 'bool',
        'highlight': 'bool',
        'department_page': 'bool',
        'emphasized': 'bool',
        'emphasized_highlight_bold_package': 'bool',
        'multi_variant': 'bool'
    }

    attribute_map = {
        'category': 'category',
        'condition': 'condition',
        'duration': 'duration',
        'has_any_quantity': 'hasAnyQuantity',
        'number_of_big_photos': 'numberOfBigPhotos',
        'number_of_photos': 'numberOfPhotos',
        'quantity': 'quantity',
        'shop': 'shop',
        'sold_quantity': 'soldQuantity',
        'type': 'type',
        'unit_price': 'unitPrice',
        'bold': 'bold',
        'highlight': 'highlight',
        'department_page': 'departmentPage',
        'emphasized': 'emphasized',
        'emphasized_highlight_bold_package': 'emphasizedHighlightBoldPackage',
        'multi_variant': 'multiVariant'
    }

    def __init__(self, category=None, condition=None, duration=None, has_any_quantity=None, number_of_big_photos=None, number_of_photos=None, quantity=None, shop=None, sold_quantity=None, type=None, unit_price=None, bold=None, highlight=None, department_page=None, emphasized=None, emphasized_highlight_bold_package=None, multi_variant=None, local_vars_configuration=None):  # noqa: E501
        """ParametersForPreviewPrice - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._category = None
        self._condition = None
        self._duration = None
        self._has_any_quantity = None
        self._number_of_big_photos = None
        self._number_of_photos = None
        self._quantity = None
        self._shop = None
        self._sold_quantity = None
        self._type = None
        self._unit_price = None
        self._bold = None
        self._highlight = None
        self._department_page = None
        self._emphasized = None
        self._emphasized_highlight_bold_package = None
        self._multi_variant = None
        self.discriminator = None

        self.category = category
        if condition is not None:
            self.condition = condition
        if duration is not None:
            self.duration = duration
        if has_any_quantity is not None:
            self.has_any_quantity = has_any_quantity
        if number_of_big_photos is not None:
            self.number_of_big_photos = number_of_big_photos
        if number_of_photos is not None:
            self.number_of_photos = number_of_photos
        if quantity is not None:
            self.quantity = quantity
        if shop is not None:
            self.shop = shop
        if sold_quantity is not None:
            self.sold_quantity = sold_quantity
        if type is not None:
            self.type = type
        self.unit_price = unit_price
        if bold is not None:
            self.bold = bold
        if highlight is not None:
            self.highlight = highlight
        if department_page is not None:
            self.department_page = department_page
        if emphasized is not None:
            self.emphasized = emphasized
        if emphasized_highlight_bold_package is not None:
            self.emphasized_highlight_bold_package = emphasized_highlight_bold_package
        if multi_variant is not None:
            self.multi_variant = multi_variant

    @property
    def category(self):
        """Gets the category of this ParametersForPreviewPrice.  # noqa: E501


        :return: The category of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: Category
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ParametersForPreviewPrice.


        :param category: The category of this ParametersForPreviewPrice.  # noqa: E501
        :type: Category
        """
        if self.local_vars_configuration.client_side_validation and category is None:  # noqa: E501
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def condition(self):
        """Gets the condition of this ParametersForPreviewPrice.  # noqa: E501

        Offer condition, if is new, used or other.  # noqa: E501

        :return: The condition of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: str
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """Sets the condition of this ParametersForPreviewPrice.

        Offer condition, if is new, used or other.  # noqa: E501

        :param condition: The condition of this ParametersForPreviewPrice.  # noqa: E501
        :type: str
        """
        allowed_values = ["NEW", "USED", "OTHER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and condition not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `condition` ({0}), must be one of {1}"  # noqa: E501
                .format(condition, allowed_values)
            )

        self._condition = condition

    @property
    def duration(self):
        """Gets the duration of this ParametersForPreviewPrice.  # noqa: E501


        :return: The duration of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this ParametersForPreviewPrice.


        :param duration: The duration of this ParametersForPreviewPrice.  # noqa: E501
        :type: str
        """
        allowed_values = ["PT72H", "PT120H", "PT168H", "PT240H", "PT336H", "PT480H", "PT720H"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and duration not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `duration` ({0}), must be one of {1}"  # noqa: E501
                .format(duration, allowed_values)
            )

        self._duration = duration

    @property
    def has_any_quantity(self):
        """Gets the has_any_quantity of this ParametersForPreviewPrice.  # noqa: E501


        :return: The has_any_quantity of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: bool
        """
        return self._has_any_quantity

    @has_any_quantity.setter
    def has_any_quantity(self, has_any_quantity):
        """Sets the has_any_quantity of this ParametersForPreviewPrice.


        :param has_any_quantity: The has_any_quantity of this ParametersForPreviewPrice.  # noqa: E501
        :type: bool
        """

        self._has_any_quantity = has_any_quantity

    @property
    def number_of_big_photos(self):
        """Gets the number_of_big_photos of this ParametersForPreviewPrice.  # noqa: E501

        If set, minimum value 0  # noqa: E501

        :return: The number_of_big_photos of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: int
        """
        return self._number_of_big_photos

    @number_of_big_photos.setter
    def number_of_big_photos(self, number_of_big_photos):
        """Sets the number_of_big_photos of this ParametersForPreviewPrice.

        If set, minimum value 0  # noqa: E501

        :param number_of_big_photos: The number_of_big_photos of this ParametersForPreviewPrice.  # noqa: E501
        :type: int
        """

        self._number_of_big_photos = number_of_big_photos

    @property
    def number_of_photos(self):
        """Gets the number_of_photos of this ParametersForPreviewPrice.  # noqa: E501

        If set, minimum value 0  # noqa: E501

        :return: The number_of_photos of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: int
        """
        return self._number_of_photos

    @number_of_photos.setter
    def number_of_photos(self, number_of_photos):
        """Sets the number_of_photos of this ParametersForPreviewPrice.

        If set, minimum value 0  # noqa: E501

        :param number_of_photos: The number_of_photos of this ParametersForPreviewPrice.  # noqa: E501
        :type: int
        """

        self._number_of_photos = number_of_photos

    @property
    def quantity(self):
        """Gets the quantity of this ParametersForPreviewPrice.  # noqa: E501

        Quantity of items to be sold. If set, minimum value 1  # noqa: E501

        :return: The quantity of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this ParametersForPreviewPrice.

        Quantity of items to be sold. If set, minimum value 1  # noqa: E501

        :param quantity: The quantity of this ParametersForPreviewPrice.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    @property
    def shop(self):
        """Gets the shop of this ParametersForPreviewPrice.  # noqa: E501

        Deprecated. Value 'true' sets the 'offer.type' field to 'shop', value 'false' to 'offer'. This field is ignored if 'offer.type' field is set.  # noqa: E501

        :return: The shop of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: bool
        """
        return self._shop

    @shop.setter
    def shop(self, shop):
        """Sets the shop of this ParametersForPreviewPrice.

        Deprecated. Value 'true' sets the 'offer.type' field to 'shop', value 'false' to 'offer'. This field is ignored if 'offer.type' field is set.  # noqa: E501

        :param shop: The shop of this ParametersForPreviewPrice.  # noqa: E501
        :type: bool
        """

        self._shop = shop

    @property
    def sold_quantity(self):
        """Gets the sold_quantity of this ParametersForPreviewPrice.  # noqa: E501

        Quantity of sold items. Relates to commission success fee. If set, minimum value 1  # noqa: E501

        :return: The sold_quantity of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: int
        """
        return self._sold_quantity

    @sold_quantity.setter
    def sold_quantity(self, sold_quantity):
        """Sets the sold_quantity of this ParametersForPreviewPrice.

        Quantity of sold items. Relates to commission success fee. If set, minimum value 1  # noqa: E501

        :param sold_quantity: The sold_quantity of this ParametersForPreviewPrice.  # noqa: E501
        :type: int
        """

        self._sold_quantity = sold_quantity

    @property
    def type(self):
        """Gets the type of this ParametersForPreviewPrice.  # noqa: E501

        Offer type. 'type' or 'shop' fields must be provided. Takes precedence over 'shop' field. Note: if type = 'advertisement' then either 'quantity' or 'soldQuantity' field must be set.  # noqa: E501

        :return: The type of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ParametersForPreviewPrice.

        Offer type. 'type' or 'shop' fields must be provided. Takes precedence over 'shop' field. Note: if type = 'advertisement' then either 'quantity' or 'soldQuantity' field must be set.  # noqa: E501

        :param type: The type of this ParametersForPreviewPrice.  # noqa: E501
        :type: str
        """
        allowed_values = ["shop", "offer", "advertisement"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def unit_price(self):
        """Gets the unit_price of this ParametersForPreviewPrice.  # noqa: E501


        :return: The unit_price of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: float
        """
        return self._unit_price

    @unit_price.setter
    def unit_price(self, unit_price):
        """Sets the unit_price of this ParametersForPreviewPrice.


        :param unit_price: The unit_price of this ParametersForPreviewPrice.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and unit_price is None:  # noqa: E501
            raise ValueError("Invalid value for `unit_price`, must not be `None`")  # noqa: E501

        self._unit_price = unit_price

    @property
    def bold(self):
        """Gets the bold of this ParametersForPreviewPrice.  # noqa: E501


        :return: The bold of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: bool
        """
        return self._bold

    @bold.setter
    def bold(self, bold):
        """Sets the bold of this ParametersForPreviewPrice.


        :param bold: The bold of this ParametersForPreviewPrice.  # noqa: E501
        :type: bool
        """

        self._bold = bold

    @property
    def highlight(self):
        """Gets the highlight of this ParametersForPreviewPrice.  # noqa: E501


        :return: The highlight of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: bool
        """
        return self._highlight

    @highlight.setter
    def highlight(self, highlight):
        """Sets the highlight of this ParametersForPreviewPrice.


        :param highlight: The highlight of this ParametersForPreviewPrice.  # noqa: E501
        :type: bool
        """

        self._highlight = highlight

    @property
    def department_page(self):
        """Gets the department_page of this ParametersForPreviewPrice.  # noqa: E501


        :return: The department_page of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: bool
        """
        return self._department_page

    @department_page.setter
    def department_page(self, department_page):
        """Sets the department_page of this ParametersForPreviewPrice.


        :param department_page: The department_page of this ParametersForPreviewPrice.  # noqa: E501
        :type: bool
        """

        self._department_page = department_page

    @property
    def emphasized(self):
        """Gets the emphasized of this ParametersForPreviewPrice.  # noqa: E501


        :return: The emphasized of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: bool
        """
        return self._emphasized

    @emphasized.setter
    def emphasized(self, emphasized):
        """Sets the emphasized of this ParametersForPreviewPrice.


        :param emphasized: The emphasized of this ParametersForPreviewPrice.  # noqa: E501
        :type: bool
        """

        self._emphasized = emphasized

    @property
    def emphasized_highlight_bold_package(self):
        """Gets the emphasized_highlight_bold_package of this ParametersForPreviewPrice.  # noqa: E501


        :return: The emphasized_highlight_bold_package of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: bool
        """
        return self._emphasized_highlight_bold_package

    @emphasized_highlight_bold_package.setter
    def emphasized_highlight_bold_package(self, emphasized_highlight_bold_package):
        """Sets the emphasized_highlight_bold_package of this ParametersForPreviewPrice.


        :param emphasized_highlight_bold_package: The emphasized_highlight_bold_package of this ParametersForPreviewPrice.  # noqa: E501
        :type: bool
        """

        self._emphasized_highlight_bold_package = emphasized_highlight_bold_package

    @property
    def multi_variant(self):
        """Gets the multi_variant of this ParametersForPreviewPrice.  # noqa: E501


        :return: The multi_variant of this ParametersForPreviewPrice.  # noqa: E501
        :rtype: bool
        """
        return self._multi_variant

    @multi_variant.setter
    def multi_variant(self, multi_variant):
        """Sets the multi_variant of this ParametersForPreviewPrice.


        :param multi_variant: The multi_variant of this ParametersForPreviewPrice.  # noqa: E501
        :type: bool
        """

        self._multi_variant = multi_variant

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParametersForPreviewPrice):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ParametersForPreviewPrice):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class OfferListingDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'category': 'OfferCategory',
        'primary_image': 'OfferListingDtoImage',
        'selling_mode': 'SellingMode',
        'sale_info': 'OfferListingDtoV1SaleInfo',
        'stock': 'OfferListingDtoV1Stock',
        'stats': 'OfferListingDtoV1Stats',
        'publication': 'OfferListingDtoV1Publication',
        'after_sales_services': 'AfterSalesServices',
        'additional_services': 'OfferAdditionalServices',
        'external': 'ExternalId',
        'delivery': 'OfferListingDtoV1Delivery'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'category': 'category',
        'primary_image': 'primaryImage',
        'selling_mode': 'sellingMode',
        'sale_info': 'saleInfo',
        'stock': 'stock',
        'stats': 'stats',
        'publication': 'publication',
        'after_sales_services': 'afterSalesServices',
        'additional_services': 'additionalServices',
        'external': 'external',
        'delivery': 'delivery'
    }

    def __init__(self, id=None, name=None, category=None, primary_image=None, selling_mode=None, sale_info=None, stock=None, stats=None, publication=None, after_sales_services=None, additional_services=None, external=None, delivery=None, local_vars_configuration=None):  # noqa: E501
        """OfferListingDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._category = None
        self._primary_image = None
        self._selling_mode = None
        self._sale_info = None
        self._stock = None
        self._stats = None
        self._publication = None
        self._after_sales_services = None
        self._additional_services = None
        self._external = None
        self._delivery = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if category is not None:
            self.category = category
        if primary_image is not None:
            self.primary_image = primary_image
        if selling_mode is not None:
            self.selling_mode = selling_mode
        if sale_info is not None:
            self.sale_info = sale_info
        if stock is not None:
            self.stock = stock
        if stats is not None:
            self.stats = stats
        if publication is not None:
            self.publication = publication
        if after_sales_services is not None:
            self.after_sales_services = after_sales_services
        if additional_services is not None:
            self.additional_services = additional_services
        if external is not None:
            self.external = external
        if delivery is not None:
            self.delivery = delivery

    @property
    def id(self):
        """Gets the id of this OfferListingDto.  # noqa: E501

        The offer ID.  # noqa: E501

        :return: The id of this OfferListingDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OfferListingDto.

        The offer ID.  # noqa: E501

        :param id: The id of this OfferListingDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this OfferListingDto.  # noqa: E501

        The title of the offer.  # noqa: E501

        :return: The name of this OfferListingDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OfferListingDto.

        The title of the offer.  # noqa: E501

        :param name: The name of this OfferListingDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def category(self):
        """Gets the category of this OfferListingDto.  # noqa: E501


        :return: The category of this OfferListingDto.  # noqa: E501
        :rtype: OfferCategory
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this OfferListingDto.


        :param category: The category of this OfferListingDto.  # noqa: E501
        :type: OfferCategory
        """

        self._category = category

    @property
    def primary_image(self):
        """Gets the primary_image of this OfferListingDto.  # noqa: E501


        :return: The primary_image of this OfferListingDto.  # noqa: E501
        :rtype: OfferListingDtoImage
        """
        return self._primary_image

    @primary_image.setter
    def primary_image(self, primary_image):
        """Sets the primary_image of this OfferListingDto.


        :param primary_image: The primary_image of this OfferListingDto.  # noqa: E501
        :type: OfferListingDtoImage
        """

        self._primary_image = primary_image

    @property
    def selling_mode(self):
        """Gets the selling_mode of this OfferListingDto.  # noqa: E501


        :return: The selling_mode of this OfferListingDto.  # noqa: E501
        :rtype: SellingMode
        """
        return self._selling_mode

    @selling_mode.setter
    def selling_mode(self, selling_mode):
        """Sets the selling_mode of this OfferListingDto.


        :param selling_mode: The selling_mode of this OfferListingDto.  # noqa: E501
        :type: SellingMode
        """

        self._selling_mode = selling_mode

    @property
    def sale_info(self):
        """Gets the sale_info of this OfferListingDto.  # noqa: E501


        :return: The sale_info of this OfferListingDto.  # noqa: E501
        :rtype: OfferListingDtoV1SaleInfo
        """
        return self._sale_info

    @sale_info.setter
    def sale_info(self, sale_info):
        """Sets the sale_info of this OfferListingDto.


        :param sale_info: The sale_info of this OfferListingDto.  # noqa: E501
        :type: OfferListingDtoV1SaleInfo
        """

        self._sale_info = sale_info

    @property
    def stock(self):
        """Gets the stock of this OfferListingDto.  # noqa: E501


        :return: The stock of this OfferListingDto.  # noqa: E501
        :rtype: OfferListingDtoV1Stock
        """
        return self._stock

    @stock.setter
    def stock(self, stock):
        """Sets the stock of this OfferListingDto.


        :param stock: The stock of this OfferListingDto.  # noqa: E501
        :type: OfferListingDtoV1Stock
        """

        self._stock = stock

    @property
    def stats(self):
        """Gets the stats of this OfferListingDto.  # noqa: E501


        :return: The stats of this OfferListingDto.  # noqa: E501
        :rtype: OfferListingDtoV1Stats
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this OfferListingDto.


        :param stats: The stats of this OfferListingDto.  # noqa: E501
        :type: OfferListingDtoV1Stats
        """

        self._stats = stats

    @property
    def publication(self):
        """Gets the publication of this OfferListingDto.  # noqa: E501


        :return: The publication of this OfferListingDto.  # noqa: E501
        :rtype: OfferListingDtoV1Publication
        """
        return self._publication

    @publication.setter
    def publication(self, publication):
        """Sets the publication of this OfferListingDto.


        :param publication: The publication of this OfferListingDto.  # noqa: E501
        :type: OfferListingDtoV1Publication
        """

        self._publication = publication

    @property
    def after_sales_services(self):
        """Gets the after_sales_services of this OfferListingDto.  # noqa: E501


        :return: The after_sales_services of this OfferListingDto.  # noqa: E501
        :rtype: AfterSalesServices
        """
        return self._after_sales_services

    @after_sales_services.setter
    def after_sales_services(self, after_sales_services):
        """Sets the after_sales_services of this OfferListingDto.


        :param after_sales_services: The after_sales_services of this OfferListingDto.  # noqa: E501
        :type: AfterSalesServices
        """

        self._after_sales_services = after_sales_services

    @property
    def additional_services(self):
        """Gets the additional_services of this OfferListingDto.  # noqa: E501


        :return: The additional_services of this OfferListingDto.  # noqa: E501
        :rtype: OfferAdditionalServices
        """
        return self._additional_services

    @additional_services.setter
    def additional_services(self, additional_services):
        """Sets the additional_services of this OfferListingDto.


        :param additional_services: The additional_services of this OfferListingDto.  # noqa: E501
        :type: OfferAdditionalServices
        """

        self._additional_services = additional_services

    @property
    def external(self):
        """Gets the external of this OfferListingDto.  # noqa: E501


        :return: The external of this OfferListingDto.  # noqa: E501
        :rtype: ExternalId
        """
        return self._external

    @external.setter
    def external(self, external):
        """Sets the external of this OfferListingDto.


        :param external: The external of this OfferListingDto.  # noqa: E501
        :type: ExternalId
        """

        self._external = external

    @property
    def delivery(self):
        """Gets the delivery of this OfferListingDto.  # noqa: E501


        :return: The delivery of this OfferListingDto.  # noqa: E501
        :rtype: OfferListingDtoV1Delivery
        """
        return self._delivery

    @delivery.setter
    def delivery(self, delivery):
        """Sets the delivery of this OfferListingDto.


        :param delivery: The delivery of this OfferListingDto.  # noqa: E501
        :type: OfferListingDtoV1Delivery
        """

        self._delivery = delivery

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OfferListingDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OfferListingDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class AdditionalServicesGroupResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'additional_services': 'list[AdditionalServiceResponse]',
        'created_at': 'datetime',
        'id': 'str',
        'updated_at': 'datetime',
        'name': 'str',
        'seller': 'Reference'
    }

    attribute_map = {
        'additional_services': 'additionalServices',
        'created_at': 'createdAt',
        'id': 'id',
        'updated_at': 'updatedAt',
        'name': 'name',
        'seller': 'seller'
    }

    def __init__(self, additional_services=None, created_at=None, id=None, updated_at=None, name=None, seller=None, local_vars_configuration=None):  # noqa: E501
        """AdditionalServicesGroupResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._additional_services = None
        self._created_at = None
        self._id = None
        self._updated_at = None
        self._name = None
        self._seller = None
        self.discriminator = None

        if additional_services is not None:
            self.additional_services = additional_services
        if created_at is not None:
            self.created_at = created_at
        if id is not None:
            self.id = id
        if updated_at is not None:
            self.updated_at = updated_at
        if name is not None:
            self.name = name
        if seller is not None:
            self.seller = seller

    @property
    def additional_services(self):
        """Gets the additional_services of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The additional_services of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: list[AdditionalServiceResponse]
        """
        return self._additional_services

    @additional_services.setter
    def additional_services(self, additional_services):
        """Sets the additional_services of this AdditionalServicesGroupResponse.


        :param additional_services: The additional_services of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: list[AdditionalServiceResponse]
        """

        self._additional_services = additional_services

    @property
    def created_at(self):
        """Gets the created_at of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The created_at of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AdditionalServicesGroupResponse.


        :param created_at: The created_at of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def id(self):
        """Gets the id of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The id of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AdditionalServicesGroupResponse.


        :param id: The id of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def updated_at(self):
        """Gets the updated_at of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The updated_at of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this AdditionalServicesGroupResponse.


        :param updated_at: The updated_at of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def name(self):
        """Gets the name of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The name of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AdditionalServicesGroupResponse.


        :param name: The name of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def seller(self):
        """Gets the seller of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The seller of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: Reference
        """
        return self._seller

    @seller.setter
    def seller(self, seller):
        """Sets the seller of this AdditionalServicesGroupResponse.


        :param seller: The seller of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: Reference
        """

        self._seller = seller

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdditionalServicesGroupResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdditionalServicesGroupResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class RefundDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'payment': 'RefundPayment',
        'reason': 'str',
        'status': 'str',
        'created_at': 'datetime',
        'total_value': 'RefundTotalValue',
        'line_items': 'list[RefundLineItem]',
        'delivery': 'InitializeRefundDelivery',
        'overpaid': 'InitializeRefundOverpaid',
        'surcharges': 'list[PaymentsSurcharge]',
        'additional_services': 'InitializeRefundAdditionalServices'
    }

    attribute_map = {
        'id': 'id',
        'payment': 'payment',
        'reason': 'reason',
        'status': 'status',
        'created_at': 'createdAt',
        'total_value': 'totalValue',
        'line_items': 'lineItems',
        'delivery': 'delivery',
        'overpaid': 'overpaid',
        'surcharges': 'surcharges',
        'additional_services': 'additionalServices'
    }

    def __init__(self, id=None, payment=None, reason=None, status=None, created_at=None, total_value=None, line_items=None, delivery=None, overpaid=None, surcharges=None, additional_services=None, local_vars_configuration=None):  # noqa: E501
        """RefundDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._payment = None
        self._reason = None
        self._status = None
        self._created_at = None
        self._total_value = None
        self._line_items = None
        self._delivery = None
        self._overpaid = None
        self._surcharges = None
        self._additional_services = None
        self.discriminator = None

        self.id = id
        if payment is not None:
            self.payment = payment
        self.reason = reason
        self.status = status
        self.created_at = created_at
        self.total_value = total_value
        if line_items is not None:
            self.line_items = line_items
        if delivery is not None:
            self.delivery = delivery
        if overpaid is not None:
            self.overpaid = overpaid
        if surcharges is not None:
            self.surcharges = surcharges
        if additional_services is not None:
            self.additional_services = additional_services

    @property
    def id(self):
        """Gets the id of this RefundDetails.  # noqa: E501

        The payment refund identifier.  # noqa: E501

        :return: The id of this RefundDetails.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RefundDetails.

        The payment refund identifier.  # noqa: E501

        :param id: The id of this RefundDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def payment(self):
        """Gets the payment of this RefundDetails.  # noqa: E501


        :return: The payment of this RefundDetails.  # noqa: E501
        :rtype: RefundPayment
        """
        return self._payment

    @payment.setter
    def payment(self, payment):
        """Sets the payment of this RefundDetails.


        :param payment: The payment of this RefundDetails.  # noqa: E501
        :type: RefundPayment
        """

        self._payment = payment

    @property
    def reason(self):
        """Gets the reason of this RefundDetails.  # noqa: E501

        Reason for a payment refund.  # noqa: E501

        :return: The reason of this RefundDetails.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this RefundDetails.

        Reason for a payment refund.  # noqa: E501

        :param reason: The reason of this RefundDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and reason is None:  # noqa: E501
            raise ValueError("Invalid value for `reason`, must not be `None`")  # noqa: E501
        allowed_values = ["REFUND", "COMPLAINT", "PRODUCT_NOT_AVAILABLE", "PAID_VALUE_TOO_LOW"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and reason not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `reason` ({0}), must be one of {1}"  # noqa: E501
                .format(reason, allowed_values)
            )

        self._reason = reason

    @property
    def status(self):
        """Gets the status of this RefundDetails.  # noqa: E501

        Current status of payment refund.  # noqa: E501

        :return: The status of this RefundDetails.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RefundDetails.

        Current status of payment refund.  # noqa: E501

        :param status: The status of this RefundDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["SUCCESS", "CANCELED", "PARTIAL", "IN_PROGRESS", "VALIDATE_FAILED", "NEW"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def created_at(self):
        """Gets the created_at of this RefundDetails.  # noqa: E501

        Date and time when the refund was created provided in ISO 8601 format.  # noqa: E501

        :return: The created_at of this RefundDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this RefundDetails.

        Date and time when the refund was created provided in ISO 8601 format.  # noqa: E501

        :param created_at: The created_at of this RefundDetails.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def total_value(self):
        """Gets the total_value of this RefundDetails.  # noqa: E501


        :return: The total_value of this RefundDetails.  # noqa: E501
        :rtype: RefundTotalValue
        """
        return self._total_value

    @total_value.setter
    def total_value(self, total_value):
        """Sets the total_value of this RefundDetails.


        :param total_value: The total_value of this RefundDetails.  # noqa: E501
        :type: RefundTotalValue
        """
        if self.local_vars_configuration.client_side_validation and total_value is None:  # noqa: E501
            raise ValueError("Invalid value for `total_value`, must not be `None`")  # noqa: E501

        self._total_value = total_value

    @property
    def line_items(self):
        """Gets the line_items of this RefundDetails.  # noqa: E501

        List of order's line items which can be refunded.  # noqa: E501

        :return: The line_items of this RefundDetails.  # noqa: E501
        :rtype: list[RefundLineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this RefundDetails.

        List of order's line items which can be refunded.  # noqa: E501

        :param line_items: The line_items of this RefundDetails.  # noqa: E501
        :type: list[RefundLineItem]
        """

        self._line_items = line_items

    @property
    def delivery(self):
        """Gets the delivery of this RefundDetails.  # noqa: E501


        :return: The delivery of this RefundDetails.  # noqa: E501
        :rtype: InitializeRefundDelivery
        """
        return self._delivery

    @delivery.setter
    def delivery(self, delivery):
        """Sets the delivery of this RefundDetails.


        :param delivery: The delivery of this RefundDetails.  # noqa: E501
        :type: InitializeRefundDelivery
        """

        self._delivery = delivery

    @property
    def overpaid(self):
        """Gets the overpaid of this RefundDetails.  # noqa: E501


        :return: The overpaid of this RefundDetails.  # noqa: E501
        :rtype: InitializeRefundOverpaid
        """
        return self._overpaid

    @overpaid.setter
    def overpaid(self, overpaid):
        """Sets the overpaid of this RefundDetails.


        :param overpaid: The overpaid of this RefundDetails.  # noqa: E501
        :type: InitializeRefundOverpaid
        """

        self._overpaid = overpaid

    @property
    def surcharges(self):
        """Gets the surcharges of this RefundDetails.  # noqa: E501

        List of surcharges for payment which can be refunded.  # noqa: E501

        :return: The surcharges of this RefundDetails.  # noqa: E501
        :rtype: list[PaymentsSurcharge]
        """
        return self._surcharges

    @surcharges.setter
    def surcharges(self, surcharges):
        """Sets the surcharges of this RefundDetails.

        List of surcharges for payment which can be refunded.  # noqa: E501

        :param surcharges: The surcharges of this RefundDetails.  # noqa: E501
        :type: list[PaymentsSurcharge]
        """

        self._surcharges = surcharges

    @property
    def additional_services(self):
        """Gets the additional_services of this RefundDetails.  # noqa: E501


        :return: The additional_services of this RefundDetails.  # noqa: E501
        :rtype: InitializeRefundAdditionalServices
        """
        return self._additional_services

    @additional_services.setter
    def additional_services(self, additional_services):
        """Sets the additional_services of this RefundDetails.


        :param additional_services: The additional_services of this RefundDetails.  # noqa: E501
        :type: InitializeRefundAdditionalServices
        """

        self._additional_services = additional_services

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RefundDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RefundDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class Error(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'str',
        'details': 'str',
        'message': 'str',
        'path': 'str',
        'user_message': 'str'
    }

    attribute_map = {
        'code': 'code',
        'details': 'details',
        'message': 'message',
        'path': 'path',
        'user_message': 'userMessage'
    }

    def __init__(self, code=None, details=None, message=None, path=None, user_message=None, local_vars_configuration=None):  # noqa: E501
        """Error - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._details = None
        self._message = None
        self._path = None
        self._user_message = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if details is not None:
            self.details = details
        if message is not None:
            self.message = message
        if path is not None:
            self.path = path
        if user_message is not None:
            self.user_message = user_message

    @property
    def code(self):
        """Gets the code of this Error.  # noqa: E501

        The error code. You can use this code when contacting us about any problems with our systems.  # noqa: E501

        :return: The code of this Error.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this Error.

        The error code. You can use this code when contacting us about any problems with our systems.  # noqa: E501

        :param code: The code of this Error.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def details(self):
        """Gets the details of this Error.  # noqa: E501

        For some cases, this field provides more details regarding the error. This field can be empty.  # noqa: E501

        :return: The details of this Error.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this Error.

        For some cases, this field provides more details regarding the error. This field can be empty.  # noqa: E501

        :param details: The details of this Error.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def message(self):
        """Gets the message of this Error.  # noqa: E501

        A message directed to the developer of the program. This message will always be in English and give you some more technical details on what exactly has happened.  # noqa: E501

        :return: The message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Error.

        A message directed to the developer of the program. This message will always be in English and give you some more technical details on what exactly has happened.  # noqa: E501

        :param message: The message of this Error.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def path(self):
        """Gets the path of this Error.  # noqa: E501

        This field will point to a specific field in object if the error is connected to a problem with such specific field. This field can be empty  # noqa: E501

        :return: The path of this Error.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this Error.

        This field will point to a specific field in object if the error is connected to a problem with such specific field. This field can be empty  # noqa: E501

        :param path: The path of this Error.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def user_message(self):
        """Gets the user_message of this Error.  # noqa: E501

        The message that can be presented directly to your user. It will not contain any technical information. This message is translated based on the value of the \"Accept-Language\" header. By default message in English is returned.  # noqa: E501

        :return: The user_message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._user_message

    @user_message.setter
    def user_message(self, user_message):
        """Sets the user_message of this Error.

        The message that can be presented directly to your user. It will not contain any technical information. This message is translated based on the value of the \"Accept-Language\" header. By default message in English is returned.  # noqa: E501

        :param user_message: The user_message of this Error.  # noqa: E501
        :type: str
        """

        self._user_message = user_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Error):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Error):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.checkout_forms import CheckoutForms  # noqa: E501
from allegro_api.rest import ApiException

class TestCheckoutForms(unittest.TestCase):
    """CheckoutForms unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CheckoutForms
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.checkout_forms.CheckoutForms()  # noqa: E501
        if include_optional :
            return CheckoutForms(
                checkout_forms = [
                    allegro_api.models.checkout_form.CheckoutForm(
                        id = '29738e61-7f6a-11e8-ac45-09db60ede9d6', 
                        message_to_seller = 'Please send me an item in red color', 
                        buyer = allegro_api.models.checkout_form_buyer_reference.CheckoutFormBuyerReference(
                            id = '23123123', 
                            email = 'user-email@allegro.pl', 
                            login = 'User_Login', 
                            first_name = 'Jan', 
                            last_name = 'Kowalski', 
                            company_name = '0', 
                            guest = False, 
                            personal_identity = '67062589524', 
                            phone_number = '0', 
                            address = allegro_api.models.checkout_form_buyer_address_reference.CheckoutFormBuyerAddressReference(
                                street = 'Solna', 
                                city = 'Poznań', 
                                post_code = '60-166', 
                                country_code = 'PL', ), ), 
                        payment = allegro_api.models.checkout_form_payment_reference.CheckoutFormPaymentReference(
                            id = '0f8f1d13-7e9e-11e8-9b00-c5b0dfb78ea6', 
                            type = 'CASH_ON_DELIVERY', 
                            provider = 'P24', 
                            finished_at = '2018-10-12T10:12:32.321Z', 
                            paid_amount = allegro_api.models.price.Price(
                                amount = '123.45', 
                                currency = 'PLN', ), ), 
                        status = 'READY_FOR_PROCESSING', 
                        fulfillment = allegro_api.models.checkout_form_fulfillment.CheckoutFormFulfillment(
                            shipment_summary = allegro_api.models.checkout_form_fulfillment_shipment_summary.CheckoutFormFulfillmentShipmentSummary(
                                line_items_sent = 'SOME', ), ), 
                        delivery = allegro_api.models.checkout_form_delivery_reference.CheckoutFormDeliveryReference(
                            method = allegro_api.models.checkout_form_delivery_method.CheckoutFormDeliveryMethod(
                                id = '1fa56f79-4b6a-4821-a6f2-ca9c16d5c925', 
                                name = 'Allegro Paczkomaty InPost', ), 
                            pickup_point = allegro_api.models.checkout_form_delivery_pickup_point.CheckoutFormDeliveryPickupPoint(
                                id = 'POZ08A', 
                                name = 'Paczkomat POZ08A', 
                                description = 'Stacja paliw BP', ), 
                            cost = allegro_api.models.price.Price(
                                amount = '123.45', 
                                currency = 'PLN', ), 
                            time = allegro_api.models.checkout_form_delivery_time.CheckoutFormDeliveryTime(
                                guaranteed = allegro_api.models.checkout_form_delivery_time_guaranteed.CheckoutFormDeliveryTimeGuaranteed(
                                    from = '2018-01-01T16:00Z', 
                                    to = '2018-01-01T18:00Z', ), ), 
                            smart = True, 
                            calculated_number_of_packages = 1, ), 
                        invoice = allegro_api.models.checkout_form_invoice_info.CheckoutFormInvoiceInfo(
                            required = True, ), 
                        line_items = [
                            allegro_api.models.checkout_form_line_item.CheckoutFormLineItem(
                                id = '62ae358b-8f65-4fc4-9c77-bedf604a2e2b', 
                                offer = allegro_api.models.offer_reference.OfferReference(
                                    id = '3213213', 
                                    name = 'Name of purchased offer', 
                                    external = allegro_api.models.external_id.ExternalId(
                                        id = 'AH-129834', ), ), 
                                quantity = 1, 
                                original_price = allegro_api.models.price.Price(
                                    amount = '123.45', 
                                    currency = 'PLN', ), 
                                price = allegro_api.models.price.Price(
                                    amount = '123.45', 
                                    currency = 'PLN', ), 
                                selected_additional_services = [
                                    allegro_api.models.checkout_form_additional_service.CheckoutFormAdditionalService(
                                        definition_id = 'CARRY_IN', 
                                        name = 'Wniesienie', 
                                        quantity = 1, )
                                    ], 
                                bought_at = '2018-01-01T10:23:43.123Z', )
                            ], 
                        surcharges = [
                            allegro_api.models.checkout_form_payment_reference.CheckoutFormPaymentReference(
                                id = '0f8f1d13-7e9e-11e8-9b00-c5b0dfb78ea6', 
                                type = 'CASH_ON_DELIVERY', 
                                finished_at = '2018-10-12T10:12:32.321Z', )
                            ], 
                        discounts = [
                            allegro_api.models.checkout_form_discount.CheckoutFormDiscount(
                                type = 'COUPON', )
                            ], 
                        summary = allegro_api.models.checkout_form_summary.CheckoutFormSummary(
                            total_to_pay = null, ), 
                        updated_at = '2011-12-03T10:15:30.133Z', )
                    ], 
                count = 1, 
                total_count = 1
            )
        else :
            return CheckoutForms(
                checkout_forms = [
                    allegro_api.models.checkout_form.CheckoutForm(
                        id = '29738e61-7f6a-11e8-ac45-09db60ede9d6', 
                        message_to_seller = 'Please send me an item in red color', 
                        buyer = allegro_api.models.checkout_form_buyer_reference.CheckoutFormBuyerReference(
                            id = '23123123', 
                            email = 'user-email@allegro.pl', 
                            login = 'User_Login', 
                            first_name = 'Jan', 
                            last_name = 'Kowalski', 
                            company_name = '0', 
                            guest = False, 
                            personal_identity = '67062589524', 
                            phone_number = '0', 
                            address = allegro_api.models.checkout_form_buyer_address_reference.CheckoutFormBuyerAddressReference(
                                street = 'Solna', 
                                city = 'Poznań', 
                                post_code = '60-166', 
                                country_code = 'PL', ), ), 
                        payment = allegro_api.models.checkout_form_payment_reference.CheckoutFormPaymentReference(
                            id = '0f8f1d13-7e9e-11e8-9b00-c5b0dfb78ea6', 
                            type = 'CASH_ON_DELIVERY', 
                            provider = 'P24', 
                            finished_at = '2018-10-12T10:12:32.321Z', 
                            paid_amount = allegro_api.models.price.Price(
                                amount = '123.45', 
                                currency = 'PLN', ), ), 
                        status = 'READY_FOR_PROCESSING', 
                        fulfillment = allegro_api.models.checkout_form_fulfillment.CheckoutFormFulfillment(
                            shipment_summary = allegro_api.models.checkout_form_fulfillment_shipment_summary.CheckoutFormFulfillmentShipmentSummary(
                                line_items_sent = 'SOME', ), ), 
                        delivery = allegro_api.models.checkout_form_delivery_reference.CheckoutFormDeliveryReference(
                            method = allegro_api.models.checkout_form_delivery_method.CheckoutFormDeliveryMethod(
                                id = '1fa56f79-4b6a-4821-a6f2-ca9c16d5c925', 
                                name = 'Allegro Paczkomaty InPost', ), 
                            pickup_point = allegro_api.models.checkout_form_delivery_pickup_point.CheckoutFormDeliveryPickupPoint(
                                id = 'POZ08A', 
                                name = 'Paczkomat POZ08A', 
                                description = 'Stacja paliw BP', ), 
                            cost = allegro_api.models.price.Price(
                                amount = '123.45', 
                                currency = 'PLN', ), 
                            time = allegro_api.models.checkout_form_delivery_time.CheckoutFormDeliveryTime(
                                guaranteed = allegro_api.models.checkout_form_delivery_time_guaranteed.CheckoutFormDeliveryTimeGuaranteed(
                                    from = '2018-01-01T16:00Z', 
                                    to = '2018-01-01T18:00Z', ), ), 
                            smart = True, 
                            calculated_number_of_packages = 1, ), 
                        invoice = allegro_api.models.checkout_form_invoice_info.CheckoutFormInvoiceInfo(
                            required = True, ), 
                        line_items = [
                            allegro_api.models.checkout_form_line_item.CheckoutFormLineItem(
                                id = '62ae358b-8f65-4fc4-9c77-bedf604a2e2b', 
                                offer = allegro_api.models.offer_reference.OfferReference(
                                    id = '3213213', 
                                    name = 'Name of purchased offer', 
                                    external = allegro_api.models.external_id.ExternalId(
                                        id = 'AH-129834', ), ), 
                                quantity = 1, 
                                original_price = allegro_api.models.price.Price(
                                    amount = '123.45', 
                                    currency = 'PLN', ), 
                                price = allegro_api.models.price.Price(
                                    amount = '123.45', 
                                    currency = 'PLN', ), 
                                selected_additional_services = [
                                    allegro_api.models.checkout_form_additional_service.CheckoutFormAdditionalService(
                                        definition_id = 'CARRY_IN', 
                                        name = 'Wniesienie', 
                                        quantity = 1, )
                                    ], 
                                bought_at = '2018-01-01T10:23:43.123Z', )
                            ], 
                        surcharges = [
                            allegro_api.models.checkout_form_payment_reference.CheckoutFormPaymentReference(
                                id = '0f8f1d13-7e9e-11e8-9b00-c5b0dfb78ea6', 
                                type = 'CASH_ON_DELIVERY', 
                                finished_at = '2018-10-12T10:12:32.321Z', )
                            ], 
                        discounts = [
                            allegro_api.models.checkout_form_discount.CheckoutFormDiscount(
                                type = 'COUPON', )
                            ], 
                        summary = allegro_api.models.checkout_form_summary.CheckoutFormSummary(
                            total_to_pay = null, ), 
                        updated_at = '2011-12-03T10:15:30.133Z', )
                    ],
                count = 1,
                total_count = 1,
        )

    def testCheckoutForms(self):
        """Test CheckoutForms"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
